==> moodle_1.3.1.orig.tar.gz: moodle/lang/th/editor.php <==
<?PHP // $Id: editor.php,v 1.1 2004/03/19 06:30:20 moodler Exp $ 
      // editor.php - created with Moodle 1.2 Beta (2004022400)


$string['about'] = 'ǡѺͧ';
$string['absbottom'] = 'ҧش';
$string['absmiddle'] = 'çҧ';
$string['address'] = '';
$string['alignment'] = 'èѴ˹';
$string['alternatetext'] = 'ͤ͸Ժ';
$string['baseline'] = 'ٻӡҹ';
$string['bold'] = '˹';
$string['borderthickness'] = '˹Ңͧͺ';
$string['bottom'] = 'ҹҧ';
$string['browse'] = 'Browse';
$string['cancel'] = '¡ԡ';
$string['cellpadding'] = 'cell padding ';
$string['cellspacing'] = 'cell spacing';
$string['choosechar'] = '͡˹ѧ';
$string['chooseicon'] = 'ͤ͡͹Ҿͧá';
$string['close'] = 'Դ';
$string['cols'] = '';
$string['copy'] = 'ͻ͡';
$string['createfolder'] = 'ҧ';
$string['createlink'] = 'áԧ';
$string['cut'] = 'Ѵ';
$string['delete'] = 'ź';
$string['filebrowser'] = ' Browser';
$string['forecolor'] = 'յ˹ѧ';
$string['heading'] = '';
$string['height'] = '٧';
$string['hilitecolor'] = 'վ';
$string['horizontal'] = '';
$string['horizontalrule'] = '鹤';
$string['htmlmode'] = ' Html';
$string['imageurl'] = 'ԧͧҾ';
$string['indent'] = '˹';
$string['insertchar'] = 'ѡþ';
$string['insertimage'] = 'áҾ';
$string['insertlink'] = 'áԧ';
$string['insertsmile'] = 'áͤ͹';
$string['inserttable'] = 'áҧ';
$string['italic'] = '§';
$string['justifycenter'] = 'Ѵ˹ҧ';
$string['justifyfull'] = 'Ѵ˹';
$string['justifyleft'] = 'Ѵҷҧ';
$string['justifyright'] = 'Ѵҷҧ';
$string['layout'] = 'ٻẺ';
$string['left'] = '';
$string['linkproperties'] = 'سѵԢͧԧ';
$string['linktarget'] = '';
$string['linktargetblank'] = '˹ҵҧ';
$string['linktargetnone'] = '';
$string['linktargetother'] = '  ';
$string['linktargetself'] = 'ǡѹ';
$string['linktargettop'] = '˹ҵҧǡѹ';
$string['linktitle'] = 'Ǣ';
$string['linkurl'] = 'URL';
$string['middle'] = 'ҧ';
$string['move'] = '';
$string['normal'] = '';
$string['notimage'] = '͡ٻҾ س͡ٻҾ';
$string['notset'] = '駤';
$string['ok'] = 'ŧ';
$string['orderedlist'] = 'ӴѺ¡';
$string['outdent'] = 'Ŵ˹';
$string['paste'] = 'ҧ';
$string['path'] = 'path';
$string['percent'] = '繵';
$string['pixels'] = 'ԡ';
$string['popupeditor'] = 'ͧ';
$string['preformatted'] = 'Preformatted';
$string['preview'] = 'preview';
$string['properties'] = 'سѵ';
$string['redo'] = '¡ԡӫ';
$string['rename'] = '¹';
$string['right'] = '';
$string['rows'] = '';
$string['selection'] = '͡';
$string['showhelp'] = 'Ըͧ';
$string['size'] = 'Ҵ';
$string['spacing'] = 'ͧҧ';
$string['strikethrough'] = 'մ';
$string['subscript'] = '';
$string['superscript'] = '¡';
$string['textindicator'] = 'Ѩغѹ';
$string['textmode'] = 'س text   <> ͷӡ¹  WYSIWYG';
$string['texttop'] = '˹ѧ躹';
$string['top'] = '';
$string['type'] = '';
$string['underline'] = 'մ';
$string['undo'] = 'ԡ';
$string['unorderedlist'] = '¡';
$string['upload'] = 'ѾŴ';
$string['vertical'] = 'ǵ';
$string['width'] = 'ҧ';
$string['zip'] = 'Ի';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/th/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 unstable development (2004083000)


$string['about'] = 'ǡѺͧ';
$string['absbottom'] = 'ҧش';
$string['middle'] = 'çҧ';
$string['address'] = '';
$string['alignment'] = 'èѴ˹';
$string['alternatetext'] = 'ͤ͸Ժ';
$string['anchorhelp'] = 'Ѻҧ anchor ҹ鹤س繵ͧҧԧ¡ҧҡ';
$string['anchorname'] = ' Anchor';
$string['anchors'] = 'Anchors';
$string['baseline'] = 'ٻӡҹ';
$string['bold'] = '˹';
$string['borderthickness'] = '˹Ңͧͺ';
$string['bottom'] = 'ҹҧ';
$string['browse'] = 'Browse';
$string['cancel'] = '¡ԡ';
$string['cellpadding'] = '';
$string['cellspacing'] = 'ͧҧҧ';
$string['choosechar'] = '͡˹ѧ';
$string['chooseicon'] = 'ͤ͡͹Ҿͧá';
$string['close'] = 'Դ';
$string['cols'] = '';
$string['copy'] = 'ͻ͡';
$string['createanchor'] = ' Anchors';
$string['createfolder'] = 'ҧ';
$string['createlink'] = 'áԧ';
$string['cut'] = 'Ѵ';
$string['delete'] = 'ź';
$string['filebrowser'] = ' Browser';
$string['forecolor'] = 'յ˹ѧ';
$string['fullscreen'] = '˹Ҩ';
$string['heading'] = '';
$string['height'] = '٧';
$string['hilitecolor'] = 'վ';
$string['horizontal'] = '';
$string['horizontalrule'] = '鹤';
$string['htmlmode'] = ' Html';
$string['imageurl'] = 'ԧͧҾ';
$string['indent'] = '˹';
$string['insertchar'] = 'ѡþ';
$string['insertimage'] = 'áҾ';
$string['insertlink'] = 'áԧ';
$string['insertsmile'] = 'áͤ͹';
$string['inserttable'] = 'áҧ';
$string['italic'] = '§';
$string['justifycenter'] = 'Ѵ˹ҧ';
$string['justifyfull'] = 'Ѵ˹';
$string['justifyleft'] = 'Ѵҷҧ';
$string['justifyright'] = 'Ѵҷҧ';
$string['layout'] = 'ٻẺ';
$string['left'] = '';
$string['lefttoright'] = 'ҡ仢';
$string['linkproperties'] = 'سѵԢͧԧ';
$string['linktarget'] = '';
$string['linktargetblank'] = '˹ҵҧ';
$string['linktargetnone'] = '';
$string['linktargetother'] = '  ';
$string['linktargetself'] = 'ǡѹ';
$string['linktargettop'] = '˹ҵҧǡѹ';
$string['linktitle'] = 'Ǣ';
$string['linkurl'] = 'URL';
$string['middle'] = 'ҧ';
$string['minimize'] = '͢Ҵ editor';
$string['move'] = '';
$string['normal'] = '';
$string['notimage'] = '͡ٻҾ س͡ٻҾ';
$string['notset'] = '駤';
$string['ok'] = 'ŧ';
$string['orderedlist'] = 'ӴѺ¡';
$string['outdent'] = 'Ŵ˹';
$string['paste'] = 'ҧ';
$string['path'] = 'path';
$string['percent'] = '繵';
$string['pixels'] = 'ԡ';
$string['popupeditor'] = 'ͧ';
$string['preformatted'] = 'Preformatted';
$string['preview'] = 'preview';
$string['properties'] = 'سѵ';
$string['redo'] = '¡ԡӫ';
$string['removelink'] = 'źԧ͡';
$string['rename'] = '¹';
$string['right'] = '';
$string['righttoleft'] = 'ҡ仫';
$string['rows'] = '';
$string['selectcolor'] = '͡';
$string['selection'] = '͡';
$string['showhelp'] = 'Ըͧ';
$string['size'] = 'Ҵ';
$string['spacing'] = 'ͧҧ';
$string['strikethrough'] = 'մ';
$string['subscript'] = '';
$string['superscript'] = '¡';
$string['textindicator'] = 'Ѩغѹ';
$string['textmode'] = 'س text   <> ͷӡ¹  WYSIWYG';
$string['texttop'] = '˹ѧ躹';
$string['top'] = '';
$string['type'] = '';
$string['underline'] = 'մ';
$string['undo'] = 'ԡ';
$string['unorderedlist'] = '¡';
$string['upload'] = 'ѾŴ';
$string['vertical'] = 'ǵ';
$string['width'] = 'ҧ';
$string['wordclean'] = 'ҧ HTML';
$string['zip'] = 'zip';

?>
